import sys

if sys.platform == 'win32' or sys.platform == 'cygwin':

  from pywinauto import application, timings
  # pywinauto docs at http://pywinauto.openqa.org/index.html

  class SystemLevelDialog(object):
    """base class for all system-level dialogs"""
    
    def __init__(self, app_title=".*Mozilla Firefox", 
                       win_title=".*Mozilla Firefox"):
      self.app = application.Application().connect_(title_re=app_title)
      self.window = self.app.window_(title_re=win_title)
      self.dlg = None

    def WaitUntilExists(self, timeout=15):
      """wait until the dialog exists, up to a maximum timeout"""
      try:
        timings.WaitUntil(timeout, .5, self.dlg.Exists)
      except timings.TimeoutError, e:
        assert False
        print "Timed out waiting for dialog to appear"
        raise e

  class SaveAsDialog(SystemLevelDialog):
    """subclass for the Save As dialog"""

    def __init__(self, app_title=".*Mozilla Firefox", 
                       win_title=".*Mozilla Firefox"):
      super(SaveAsDialog, self).__init__(app_title, win_title)
      self.dlg = self.app.SaveAs

    def SetFilename(self, filename):
      """Set the filename in the edit field"""
      self.dlg.Edit.SetEditText(filename)

    def ClickSave(self):
      """Click the Save button, and handle the overwrite prompt
      if it appears"""
      self.dlg.Save.Click()
      # wait a few seconds to see if a confirm dialog appears, and if so
      # press the "yes" button, to overwrite the original file
      try:
        timings.WaitUntil(2, .5, self.app.ConfirmSaveAs.Exists)
        self.app.ConfirmSaveAs.Yes.CloseClick()
      except timings.TimeoutError, e:
        # no error here, it just means the Confirm dialog never appeared
        pass
      except WindowAmbiguousError, e:
        assert False
        for w in e.windows:
          w = HwndWrapper(w)
          print w.WindowText(), w.Class()
        raise e
